/* Copyright Airship and Contributors */

#import <Foundation/Foundation.h>
#import "UAAuthToken+Internal.h"
#import "UAAirshipAutomationCoreImport.h"

NS_ASSUME_NONNULL_BEGIN

/**
 * Represents possible auth token API client errors.
 */
typedef NS_ENUM(NSInteger, UAAuthTokenAPIClientError) {
    /**
     * Indicates an unsuccessful status error.
     */
    UAAuthTokenAPIClientErrorUnsuccessfulStatus,

    /**
     * Indicates an invalid server response.
     */
    UAAuthTokenAPIClientErrorInvalidResponse
};

/**
 * The domain for NSErrors generated by `tokenWithCompletionHandler:`.
 */
extern NSString * const UAAuthTokenAPIClientErrorDomain;

/**
 * API client for retrieving auth tokens from the server.
 */
@interface UAAuthTokenAPIClient : NSObject

/**
 * UAAuthTokenAPIClient class factory method. Used for testing.
 *
 * @param config The runtime config.
 * @param session The request session.
 */
+ (instancetype)clientWithConfig:(UARuntimeConfig *)config session:(UARequestSession *)session;

/**
 * UAAuthTokenAPIClient class factory method.
 *
 * @param config The runtime config.
 */
+ (instancetype)clientWithConfig:(UARuntimeConfig *)config;

/**
 * Retrieves the token associated with the provided channel ID.
 *
 * @param channelID The channel ID.
 * @param completionHandler The completion handler invoked with the retrieved auth token, or nil and an NSError if the request fails.
 */
- (void)tokenWithChannelID:(NSString *)channelID completionHandler:(void (^)(UAAuthToken * _Nullable, NSError * _Nullable))completionHandler;

@end

NS_ASSUME_NONNULL_END
